mod node;
mod account;

use std::sync::Arc;

use axum::{routing::get, Extension, Router};
use sqlx::{Pool, Postgres};
use tower_http::trace::TraceLayer;

use crate::{app_state::AppState, config::Config};

pub fn new(pool: Pool<Postgres>, config: Config) -> Router {
    let app_state = Arc::new(AppState { pool, config });

    let app = Router::new()
        .merge(account::router())
        .route("/_fox/ident/node", get(node::get_node))
        .route("/_fox/ident/node/:domain", get(node::get_chat_node))
        .layer(TraceLayer::new_for_http())
        .layer(Extension(app_state));

    return app;
}
