use std::sync::Arc;

use axum::{Extension, Json, extract::Path};
use eyre::{Context, Result};
use foxchat::http::ApiError;
use rsa::pkcs1::EncodeRsaPublicKey;
use serde::Serialize;

use crate::{app_state::AppState, model::{instance::Instance, chat_instance::ChatInstance}};

pub async fn get_node(
    Extension(state): Extension<Arc<AppState>>,
) -> Result<Json<NodeResponse>, ApiError> {
    let instance = Instance::get(&state.pool).await?;

    let public_key = instance
        .public_key
        .to_pkcs1_pem(rsa::pkcs8::LineEnding::LF)
        .wrap_err("serializing public key")?;

    Ok(Json(NodeResponse {
        software: NODE_SOFTWARE,
        public_key,
    }))
}

const NODE_SOFTWARE: &str = "foxchat_ident";

#[derive(Serialize)]
pub struct NodeResponse {
    pub software: &'static str,
    pub public_key: String,
}

pub async fn get_chat_node(
    Extension(state): Extension<Arc<AppState>>,
    Path(domain): Path<String>,
) -> Result<Json<ChatInstance>, ApiError> {
    let instance = ChatInstance::get(state, domain).await?;

    Ok(Json(instance))
}
